@@ -4,13 +4,14 @@
 @version: beta
 @Author: xiaoshuyui
 @Date: 2020-07-10 10:33:39
-@LastEditors: xiaoshuyui
-@LastEditTime: 2020-07-13 14:21:34
+LastEditors: xiaoshuyui
+LastEditTime: 2020-08-19 17:16:39
 '''
 
 from . import getMultiShapes
 import glob
 import os
+from tqdm import tqdm
 
 def getJsons(imgPath,maskPath,savePath,yamlPath = ''):
     """
@@ -24,7 +25,7 @@ def getJsons(imgPath,maskPath,savePath,yamlPath = ''):
     oriImgs = glob.glob(imgPath+os.sep+'*.jpg')
     maskImgs = glob.glob(maskPath+os.sep+'*.jpg')
     
-    for i in oriImgs:
+    for i in tqdm(oriImgs):
         i_mask = i.replace(imgPath,maskPath)
         print(i)
 
@@ -34,7 +35,7 @@ def getXmls(imgPath,maskPath,savePath):
     oriImgs = glob.glob(imgPath+os.sep+'*.jpg')
     maskImgs = glob.glob(maskPath+os.sep+'*.jpg')
     
-    for i in oriImgs:
+    for i in tqdm(oriImgs):
         i_mask = i.replace(imgPath,maskPath)
         print(i)
 
